@@ -14,6 +14,7 @@ from cimsparql.cim import (
     TR_WINDING,
 )
 from cimsparql.constants import allowed_load_types, mrid_variable, sequence_numbers, union_split
+from cimsparql.transformer_windings import number_of_windings, terminal, transformer_common
 
 
 def version_date() -> str:
@@ -53,7 +54,7 @@ def phase_tap_changer_query(
     tap_changer_objects: Iterable[str],
     mrid: str,
 ) -> str:
-    variables = [mrid]
+    variables = [mrid, "?w_mrid_1", "?w_mrid_2", "?t_mrid_1", "?t_mrid_2"]
     tap = "?tap"
     where_list = [
         sup.rdf_type_tripler(mrid, TR_WINDING),
@@ -73,19 +74,18 @@ def phase_tap_changer_query(
 
     if impedance is not None:
         variables.extend(sup.to_variables(impedance))
-        where_list.extend([f"?pte_1 {TR_WINDING}.{imp} ?{imp}" for imp in impedance])
+        where_list.extend([f"?w_mrid_1 {TR_WINDING}.{imp} ?{imp}" for imp in impedance])
 
     if region is not None:
         where_list.extend([f"?pt {EQUIP_CONTAINER} ?Substation"])
         where_list.extend(sup.region_query(region, sub_region, "Substation", "?subgeoreg"))
 
     for i in sequence_numbers:
-        variables.append(f"?t_mrid_{i}")
         where_list.extend(
             [
                 sup.rdf_type_tripler(f"?term_{i}", "cim:Terminal"),
-                f"?pte_{i} {TR_WINDING}.PowerTransformer ?pt",
-                f"?pte_{i} cim:TransformerEnd.Terminal ?term_{i}",
+                f"?w_mrid_{i} {TR_WINDING}.PowerTransformer ?pt",
+                f"?w_mrid_{i} cim:TransformerEnd.Terminal ?term_{i}",
                 f'?term_{i} cim:Terminal.sequenceNumber "{i}"^^xsd:integer',
                 f"?term_{i} {ID_OBJ}.mRID ?t_mrid_{i}",
             ]
@@ -302,6 +302,62 @@ def wind_generating_unit_query(network_analysis: bool, mrid: str, name: str):
     return sup.combine_statements(sup.select_statement(variables), sup.group_query(where_list))
 
 
+def two_winding_transformer_query(
+    region: Union[str, List[str]],
+    sub_region: bool,
+    rates: Iterable[str],
+    network_analysis: bool,
+    with_market: bool,
+    mrid: str,
+    name: str,
+    impedance: Iterable[str],
+) -> str:
+    variables = ["?t_mrid_1", "?t_mrid_2"]
+    where_list = [*terminal(mrid, 1), *terminal(mrid, 2)]
+    transformer_common(
+        2,
+        mrid,
+        name,
+        impedance,
+        variables,
+        where_list,
+        with_market,
+        region,
+        sub_region,
+        rates,
+        network_analysis,
+    )
+    return sup.combine_statements(sup.select_statement(variables), sup.group_query(where_list))
+
+
+def three_winding_transformer_query(
+    region: Union[str, List[str]],
+    sub_region: bool,
+    rates: Iterable[str],
+    network_analysis: bool,
+    with_market: bool,
+    mrid: str,
+    name: str,
+    impedance: Iterable[str],
+) -> str:
+    variables = ["?t_mrid_1", f"({mrid} as ?t_mrid_2)"]
+    where_list = [*terminal(mrid, 1, lock_end_number=False)]
+    transformer_common(
+        3,
+        mrid,
+        name,
+        impedance,
+        variables,
+        where_list,
+        with_market,
+        region,
+        sub_region,
+        rates,
+        network_analysis,
+    )
+    return sup.combine_statements(sup.select_statement(variables), sup.group_query(where_list))
+
+
 def transformer_query(
     region: Union[str, List[str]],
     sub_region: bool,
